@@ -35,7 +35,7 @@
 namespace LIFEO
 {
 
-// SAVERS & EXPORTERS
+// EXPORTERS =======================================================================================
 class Diarysaver
 {
 	public:
@@ -44,7 +44,7 @@ class Diarysaver
 
 		virtual Gtk::Widget*		draw_options( void ) = 0;
 		virtual bool				is_ready( void ) = 0;
-		virtual Result				save( const std::string& ) = 0;
+		virtual Result				save( const std::string&, bool ) = 0;
 
 		Glib::ustring				get_name( void )
 		{ return m_name; }
@@ -61,33 +61,24 @@ class Diarysaver
 		Signal_void_bool			m_signal_updated;
 };
 
-class SaverEncrypted : public Diarysaver
+class ExporterLifeograph : public Diarysaver
 {
 	public:
-		explicit					SaverEncrypted( Diary* );
-		Gtk::Widget*				draw_options( void );
-		bool						is_ready( void );
-		Result						save( const std::string& );
+        explicit                    ExporterLifeograph( Diary* );
+        Gtk::Widget*                draw_options( void );
+        bool                        is_ready( void );
+        Result                      save( const std::string&, bool );
 
-		void						handle_passphrase_changed( void );
+        void                        handle_passphrase_changed( void );
+        void                        handle_encryption_changed( void );
 
-	private:
-		Gtk::Entry					*m_entry_passphrase;
-		Gtk::Entry					*m_entry_confirm;
-		std::string					m_passphrase;
-};
+    private:
+        Gtk::CheckButton            *m_check_encrypt;
+        Gtk::Entry                  *m_entry_passphrase;
+        Gtk::Entry                  *m_entry_confirm;
+        std::string                 m_passphrase;
 
-class SaverUnencrypted : public Diarysaver
-{
-	public:
-		explicit					SaverUnencrypted( Diary* );
-		Gtk::Widget*				draw_options( void )
-		{ return NULL; }
-
-		bool						is_ready( void )
-		{ return true; }
-
-		Result						save( const std::string& );
+        bool                        m_flag_encrypted;
 };
 
 class ExporterText : public Diarysaver
@@ -100,7 +91,7 @@ class ExporterText : public Diarysaver
 		bool						is_ready( void )
 		{ return true; }
 
-		Result						save( const std::string& );
+		Result						save( const std::string&, bool );
 };
 
 // FILE SELECTION DIALOG
@@ -110,7 +101,7 @@ class DialogSaveDiary : public Gtk::FileChooserDialog
 									DialogSaveDiary();
 };
 
-// PASSWORD PROMPT DIALOG ======================================================
+// PASSWORD PROMPT DIALOG ==========================================================================
 class DialogPasswordPrompt : public DialogEvent
 {
 	public:
@@ -127,12 +118,12 @@ class DialogPasswordPrompt : public DialogEvent
 	friend class DialogImport;
 };
 
-// IMPORT DIALOG ===============================================================
+// IMPORT DIALOG ===================================================================================
 class DialogImport : public DialogEvent
 {
 	public:
-									DialogImport( BaseObjectType*,
-												  const Glib::RefPtr< Gtk::Builder >& );
+                                    DialogImport( BaseObjectType*,
+                                                  const Glib::RefPtr< Gtk::Builder >& );
 
 		void						on_show( void );
 		void						on_response( int );
@@ -150,13 +141,13 @@ class DialogImport : public DialogEvent
 		Gtk::Label					*m_label_info;
 		Gtk::Label					*m_label_entries;
 		Gtk::Label					*m_label_tags;
-		Gtk::Label					*m_label_chapters;
+		Gtk::Label					*m_label_themes;
 		TagWidget					*m_tag_widget;
 		Gtk::Entry					*m_entry_password;
 
 		Gtk::CheckButton			*m_checkbutton_import_entries;
 		Gtk::CheckButton			*m_checkbutton_import_tags;
-		Gtk::CheckButton			*m_checkbutton_import_chapters;
+		Gtk::CheckButton			*m_checkbutton_import_themes;
 
 		DialogPasswordPrompt		*m_dialog_password;
 
@@ -164,16 +155,17 @@ class DialogImport : public DialogEvent
 
 		bool						m_option_import_entries;
 		bool						m_option_import_tags;
-		bool						m_option_import_chapters;
+		bool						m_option_import_themes;
 		bool						m_flag_diary_is_ready;
 
 };
 
-// EXPORT DIALOG ===============================================================
+// EXPORT DIALOG ===================================================================================
 class DialogExport : public DialogEvent
 {
 	public:
-		explicit					DialogExport( Diary* );
+                                    DialogExport( BaseObjectType*,
+                                                  const Glib::RefPtr< Gtk::Builder >& );
 
 		void						add_saver( Diarysaver* );
 
@@ -182,28 +174,19 @@ class DialogExport : public DialogEvent
 
 		void						handle_savetype_changed( void );
 		void						handle_saver_updated( bool );
-		void						handle_path_changed( void );
-		void						handle_overwrite_toggled( void );
-		void						handle_browse(	Gtk::EntryIconPosition,
-													const GdkEventButton* );
 
-		Gtk::Widget*				draw_options_encrypted( void );
-
-		bool						is_ready( void );
-
-		Gtk::Entry					m_entry_path;
-		Gtk::CheckButton			m_checkbutton_overwrite;
-		Gtk::ComboBoxText			m_combobox;
-		Gtk::Table					m_table;
-		Gtk::Button					*m_button_save;
-		Gtk::Widget					*m_ptr2widget_options;
+        ComboboxEasy                *m_combo_type;
+        ComboboxEasy                *m_combo_extent;
+        Gtk::Button                 *m_button_export;
+        Gtk::Alignment              *m_align_options;
+        Gtk::Frame                  *m_frame_options;
+        Gtk::Widget                 *m_ptr2widget_options;
 
 		std::vector< Diarysaver* >
 									m_savers;
+		Diarysaver                  *m_saver_cur;
 
 		Diary						*m_ptr2diary;
-
-		bool						m_flag_fileready;
 		bool						m_flag_saverready;
 
 	private:
