@@ -50,8 +50,6 @@ class DialogPreferences : public DialogEvent
 		Gtk::CheckButton		*m_chkbtn_autologout;
 		Gtk::HBox				*m_hbox_max_idle_time;
 		Gtk::SpinButton			*m_spinbutton_max_idle_time;
-		Gtk::CheckButton		*m_chkbtn_bg_image;
-		Gtk::FileChooserButton	*m_filebutton_bg_image;
 		Gtk::CheckButton		*m_chkbtn_formatting_toolbar;
 
 	private:
