@@ -74,32 +74,18 @@ get_db_line_name( const Glib::ustring &line )
 }
 
 // DIARY ===========================================================================================
-Diary::Diary( const std::string &path )
-:   DiaryElement( this ), m_path( path ), m_passphrase( "" ),
-    m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
-    m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
-    m_last_elem( DEID_MIN ),
-    m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
-    m_filter_text( "" ), m_filter_tag( NULL ), m_filter_date_begin( 0 ),
-    m_filter_date_end( Date::DATE_MAX ), m_filtering_status( FS_CLEAR )
-{
-	// "touch" new lock:
-	std::string path_lock = m_path + LOCK_SUFFIX;
-	FILE *fp = fopen( path_lock.c_str(), "a+" );
-	if( fp )
-		fclose( fp );
-
-	// add system theme to the pool where it will remain till the diary is destroyed:
-	m_themes.insert( PoolThemes::value_type( m_default_theme->get_name(), m_default_theme ) );
-}
-
-// derived classes should use this
 Diary::Diary( void )
 :   DiaryElement( this ), m_path( "" ), m_passphrase( "" ),
     m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
     m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
     m_last_elem( DEID_MIN ),
     m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+    m_flag_ignore_locks( true ),
+#else
+    m_flag_ignore_locks( false ),
+#endif
+    m_flag_read_only( false ),
     m_filter_text( "" ), m_filter_tag( NULL ), m_filter_date_begin( 0 ),
     m_filter_date_end( Date::DATE_MAX ), m_filtering_status( FS_CLEAR )
 {
@@ -119,11 +105,11 @@ Diary::~Diary( void )
 void
 Diary::init_new( const std::string &path )
 {
-	// this function must only be called on a reset diary
-	set_path( path );
-	add_today();
-	// every diary must at least have one chapter category:
-	m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
+    clear();
+    set_path( path );
+    add_today();
+    // every diary must at least have one chapter category:
+    m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
 }
 
 void
@@ -170,25 +156,37 @@ Diary::get_icon( void ) const
 	return Lifeobase::icons->diary_16;
 }
 
-void
+bool
 Diary::set_path( const std::string &path )
 {
 	std::string path_lock;
 
-	if( ! m_path.empty() )
-	{
-		path_lock = m_path + LOCK_SUFFIX;
-		remove( path_lock.c_str() );
-	}
+    // remove existing lock
+    if( ! m_path.empty() )
+    {
+        path_lock = m_path + LOCK_SUFFIX;
+        remove( path_lock.c_str() );
+    }
+
+    path_lock = path + LOCK_SUFFIX;
+    if( Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
+    {
+        if( m_flag_ignore_locks )
+            print_info( "ignored file lock" );
+        else
+        if( ! m_flag_read_only )
+            return false;
+    }
 
 	m_path = path;
+	m_name = Glib::filename_display_basename( path );
 
 	// "touch" new lock
-	// BEWARE: Diary( const std::string& ) also uses this algorithm
-	path_lock = m_path + LOCK_SUFFIX;
 	FILE *fp = fopen( path_lock.c_str(), "a+" );
 	if( fp )
 		fclose( fp );
+
+    return true;
 }
 
 const std::string&
@@ -273,7 +271,7 @@ Diary::read_header()
 				}
 				break;
 			case 'E':
-				if( line[ 2 ] != 'n' )
+				if( line[ 2 ] == 'y' )
 					// passphrase is set to a dummy value to indicate that diary
 					// is an encrypted one until user enters the real passphrase
 					m_passphrase = " ";
@@ -281,7 +279,7 @@ Diary::read_header()
 					m_passphrase.clear();
 				break;
 			case 0: // end of header
-				BodyPosition = file.tellg();
+				m_body_position = file.tellg();
 				file.close();
 				return LIFEO::SUCCESS;
 			default:
@@ -317,7 +315,7 @@ Diary::read_plain()
 
 	file.seekg( 0, std::ios::end );
 
-	int readsize = file.tellg() - BodyPosition - 1;
+	int readsize = file.tellg() - m_body_position - 1;
 
 	if( readsize <= 0 )
 	{
@@ -326,7 +324,7 @@ Diary::read_plain()
 		return LIFEO::CORRUPT_FILE;
 	}
 
-	file.seekg( BodyPosition );
+	file.seekg( m_body_position );
 
 	char *readbuffer = new char[ readsize + 1 ];
 	// TODO: check validity
@@ -355,7 +353,7 @@ Diary::read_encrypted()
 		print_error( "Failed to open diary file" + m_path );
 		return LIFEO::COULD_NOT_START;
 	}
-	file.seekg( BodyPosition );
+	file.seekg( m_body_position );
 
 	std::string line, content;
 	unsigned char *buffer;
@@ -545,7 +543,7 @@ Diary::parse_db_body_text( std::stringstream &stream )
 				set_force_id( LIFEO::convert_string( line.substr( 2 ) ) );
 				break;
 			case 'E':	// new entry
-				entry_new = new Entry( this, Date( LIFEO::convert_string( line.substr( 2 ) ) ),
+				entry_new = new Entry( this, LIFEO::convert_string( line.substr( 2 ) ),
 									   line[ 1 ] == 'f' );
 				if( m_read_version < 74 )
 					entry_new->m_date.m_date++;	// entry orders should start from 1
@@ -639,7 +637,7 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 {
 	std::string			line( "" );
 	Glib::ustring		content( "" );
-	Date				date( 0 );
+	Date::date_t		date( 0 );
 	bool				flag_favorite( false );
 	Entry				*entry_new = NULL;
 	CategoryChapters	*ptr2chapter_ctg = NULL;
@@ -756,10 +754,10 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 			case 'A':	// date
 			{	// FIXME: temporary (for compatibility)
 				Date::date_t date_new = LIFEO::convert_string( line.substr( 2 ) );
-				if( date_new == ( date.m_date >> 10 ) )
-					date.m_date++;
+				if( date_new == ( date >> 10 ) )
+					date++;
 				else
-					date.m_date = ( date_new << 10 ) + 1;
+					date = ( date_new << 10 ) + 1;
 				break;
 			}
 			case 'C':    // content
@@ -799,7 +797,7 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 				}
 				// TODO: per entry spellcheck options
 				//entry_new->set_spellcheck( opt_spell );
-				m_entries[ date.m_date ] = entry_new;
+				m_entries[ date ] = entry_new;
 
 				content.clear();
 				str_tags.clear();
@@ -1079,23 +1077,24 @@ Diary::create_db_body_text( std::stringstream &output )
 		 ++iter )
 	{
 		if( iter->second->get_category() == NULL )
-			output << "ID" << iter->second->get_id() << "\nt " << iter->first << '\n';
+            output << "ID" << iter->second->get_id()
+                   << "\nt " << iter->second->get_name_std() << '\n';
 	}
 	// CATEGORIZED TAGS
 	for( PoolCategoriesTags::const_iterator iter = m_tag_categories.begin();
 		 iter != m_tag_categories.end();
 		 ++iter )
 	{
-		output << "ID" << iter->second->get_id() << "\nT" <<
-				( iter->second->get_expanded() ? 'e' : ' ' ) <<
-				iter->first << '\n';	// tag category
+		output << "ID" << iter->second->get_id()
+               << "\nT" << ( iter->second->get_expanded() ? 'e' : ' ' )
+               << iter->second->get_name_std() << '\n';	// tag category
 		CategoryTags *category( iter->second );
 		for( CategoryTags::const_iterator iter_tag = category->begin();
 			 iter_tag != category->end();
 			 ++iter_tag )
 		{
-			output << "ID" << ( *iter_tag )->get_id() << "\nt " <<
-					( *iter_tag )->get_name() << '\n';
+            output << "ID" << ( *iter_tag )->get_id()
+                   << "\nt "<< ( *iter_tag )->get_name_std() << '\n';
 		}
 	}
 	// TOPICS
@@ -1103,28 +1102,28 @@ Diary::create_db_body_text( std::stringstream &output )
 		 iter_chapter != m_topics.end();
 		 ++iter_chapter )
 	{
-		output << "ID" << iter_chapter->second->get_id() << "\no" <<
-				( iter_chapter->second->get_expanded() ? 'e' : ' ' ) <<
-				iter_chapter->first << '\t' <<
-				iter_chapter->second->get_name() << '\n';
+        output << "ID" << iter_chapter->second->get_id()
+               << "\no" <<	( iter_chapter->second->get_expanded() ? 'e' : ' ' )
+               << iter_chapter->first   // date (order)
+               << '\t' << iter_chapter->second->get_name_std() << '\n';
 	}
 	// CHAPTERS
 	for( PoolCategoriesChapters::iterator iter = m_chapter_categories.begin();
 		 iter != m_chapter_categories.end();
 		 ++iter )
 	{
-		output << "ID" << iter->second->get_id() << "\nC" <<
-				( iter->second == m_ptr2chapter_ctg_cur ? 'c' : ' ' ) <<
-				iter->first << '\n';
 		CategoryChapters *category( iter->second );
+        output << "ID" << category->get_id()
+               << "\nC" << ( category == m_ptr2chapter_ctg_cur ? 'c' : ' ' )
+               << category->get_name_std() << '\n';
 		for( CategoryChapters::iterator iter_chapter = category->begin();
 			 iter_chapter != category->end();
 			 ++iter_chapter )
 		{
-			output << "ID" << iter_chapter->second->get_id() << "\nc" <<
-					( iter_chapter->second->get_expanded() ? 'e' : ' ' ) <<
-					iter_chapter->first << '\t' <<
-					iter_chapter->second->get_name() << '\n';
+            output << "ID" << iter_chapter->second->get_id()
+                   << "\nc" << ( iter_chapter->second->get_expanded() ? 'e' : ' ' )
+                   << iter_chapter->first   // date
+                   << '\t' << iter_chapter->second->get_name_std() << '\n';
 		}
 	}
 	// THEMES
@@ -1137,14 +1136,15 @@ Diary::create_db_body_text( std::stringstream &output )
 		if( theme->is_system() )
 			continue;
 
-		output << "ID" << theme->get_id() << "\nM" <<
-		( theme == m_default_theme ? 'd' : ' ' ) << theme->m_name << '\n';
-		output << "mf" << theme->font.to_string() << '\n';
-		output << "mb" << theme->color_base.to_string() << '\n';
-		output << "mt" << theme->color_text.to_string() << '\n';
-		output << "mh" << theme->color_heading.to_string() << '\n';
-		output << "ms" << theme->color_subheading.to_string() << '\n';
-		output << "ml" << theme->color_highlight.to_string() << '\n';
+        output << "ID" << theme->get_id()
+               << "\nM" << ( theme == m_default_theme ? 'd' : ' ' )
+               << theme->get_name_std() << '\n';
+        output << "mf" << theme->font.to_string() << '\n';
+        output << "mb" << theme->color_base.to_string() << '\n';
+        output << "mt" << theme->color_text.to_string() << '\n';
+        output << "mh" << theme->color_heading.to_string() << '\n';
+        output << "ms" << theme->color_subheading.to_string() << '\n';
+        output << "ml" << theme->color_highlight.to_string() << '\n';
 	}
 
 	output << '\n'; // end of section
@@ -1164,21 +1164,21 @@ Diary::create_db_body_text( std::stringstream &output )
 
 
 		// ENTRY DATE
-		output << "ID" << entry->get_id() << "\nE" <<
-				( entry->m_option_favored ? 'f' : ' ' ) <<
-				entry->m_date.m_date << '\n';
-		output << "Dr" << entry->m_date_created << '\n';
-		output << "Dh" << entry->m_date_changed << '\n';
+        output << "ID" << entry->get_id()
+               << "\nE" << ( entry->m_option_favored ? 'f' : ' ' )
+               << entry->m_date.m_date << '\n';
+        output << "Dr" << entry->m_date_created << '\n';
+        output << "Dh" << entry->m_date_changed << '\n';
 
 		// THEME
 		if( entry->get_theme_is_set() )
-			output << "M " << entry->get_theme()->get_name() << '\n';
+			output << "M " << entry->get_theme()->get_name_std() << '\n';
 
 		// TAGS
 		for( Tagset::const_iterator iter_tag = entry->m_tags.begin();
 			 iter_tag != entry->m_tags.end();
 			 ++iter_tag )
-			output << "T " << ( *iter_tag )->get_name() << '\n';
+			output << "T " << ( *iter_tag )->get_name_std() << '\n';
 		// CONTENT
 		// NOTE: for some reason, implicit conversion from Glib:ustring...
 		// ...fails while substr()ing when LANG=C
@@ -1277,12 +1277,7 @@ Diary::get_prev_session_elem( void )
 Entry*
 Diary::add_today( void )
 {
-	Glib::Date date;
-	date.set_time_current();
-
-	return create_entry( Date( date.get_year(),
-							   date.get_month(),
-							   date.get_day() ) );
+    return create_entry( Date::get_today() );
 }
 
 Entry*
@@ -1299,11 +1294,7 @@ Diary::get_entry( const Date::date_t date )
 Entry*
 Diary::get_entry_today( void )
 {
-	time_t t = time( NULL );
-	struct tm *ti = localtime( &t );
-	Date date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday, 1 );
-
-	return get_entry( date.m_date );
+    return get_entry( Date::get_today( 1 ) );  // 1 is the order
 }
 
 Entryvector*
@@ -1396,18 +1387,18 @@ Diary::is_last( Entry const*const entry ) const
 }
 
 Entry*
-Diary::create_entry( Date date, const Glib::ustring &content, bool flag_favorite )
+Diary::create_entry( Date::date_t date, const Glib::ustring &content, bool flag_favorite )
 {
 	// make it the last entry of its day:
-	date.reset_order_1();
-	while( m_entries.find( date.m_date ) != m_entries.end() )
-		++date.m_date;
+	Date::reset_order_1( date );
+	while( m_entries.find( date ) != m_entries.end() )
+		++date;
 
 	Entry *entry = new Entry( this, date, content, flag_favorite );
 	entry->m_date_created = time( NULL );
 	entry->m_date_changed = entry->m_date_created;
 
-	m_entries[ date.m_date ] = entry;
+	m_entries[ date ] = entry;
 
 	return( entry );
 }
@@ -1730,8 +1721,8 @@ Diary::dismiss_chapter_ctg( CategoryChapters *category )
 	if( category == m_ptr2chapter_ctg_cur )
 		m_ptr2chapter_ctg_cur = m_chapter_categories.begin()->second;
 
-	delete category;
 	m_chapter_categories.erase( category->get_name() );
+    delete category;
 }
 
 void
@@ -1942,7 +1933,7 @@ Diary::import_entryset( const PoolEntries &set,
 	{
 		entry_ext = iter->second;
 		entry_new = new Entry( this,
-							   entry_ext->m_date,
+							   entry_ext->m_date.m_date,
 							   entry_ext->m_text,
 							   entry_ext->m_option_favored );
 
