@@ -90,7 +90,7 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             case '\n':
             case '\r':
                 process_char( LF_NEWLINE,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_FORMATCHAR|
+                              LF_NUM_CKBX|LF_ALPHA|LF_FORMATCHAR|
                               LF_SLASH|LF_DOTDATE|LF_MORE|LF_TAB|LF_IGNORE,
                               0, NULL,
                               CC_NEWLINE );
@@ -103,37 +103,37 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
                 break;
             case '*':
                 process_char( LF_ASTERISK,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_bold,
                               CC_SIGN );
                 break;
             case '_':
                 process_char( LF_UNDERSCORE,
-                              LF_NUM_SPCIM_CHK|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_italic,
                               CC_SIGN );
                 break;
             case '=':
                 process_char( LF_EQUALS,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_strikethrough,
                               CC_SIGN );
                 break;
             case '#':
                 process_char( LF_HASH,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_highlight,
                               CC_SIGN );
                 break;
             case '[':
                 process_char( LF_SBB,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_comment,
                               CC_SIGN );
                 break;
             case ']':
                 process_char( LF_SBE,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               0, NULL,
                               CC_SIGN );
                 break;
@@ -147,37 +147,37 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
                 break;
             case '.':
                 process_char( LF_DOTDATE,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH,
                               LF_NOTHING, &EntryParser::trigger_ignore,
                               CC_SIGN );
                 break;
             case '/':
                 process_char( LF_SLASH|LF_DOTDATE,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA,
+                              LF_NUM_CKBX|LF_ALPHA,
                               0, NULL,
                               CC_SIGN );
                 break;
             case ':':
                 process_char( LF_PUNCTUATION_RAW,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_link,
                               CC_SIGN );
                 break;
             case '@':
                 process_char( LF_AT,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_link_at,
                               CC_SIGN );
                 break;
             case '>':
                 process_char( LF_MORE,
-                              LF_NUM_SPCIM_CHK|LF_ALPHA|LF_SLASH|LF_DOTDATE,
+                              LF_NUM_CKBX|LF_ALPHA|LF_SLASH|LF_DOTDATE,
                               0, NULL,
                               CC_SIGN );
                 break;
             case '\t':
                 process_char( LF_TAB,
-                              LF_NUM_SPCIM_SLH|LF_ALPHA|LF_DOTDATE,
+                              LF_NUM_SLSH|LF_ALPHA|LF_DOTDATE,
                               LF_NOTHING, &EntryParser::trigger_list,
                               CC_TAB );
                 break;
@@ -186,13 +186,13 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             case L'☑':
             case L'☒':
                 process_char( LF_CHECKBOX,
-                              LF_NUM_SPCIM_SLH|LF_ALPHA|LF_DOTDATE,
+                              LF_NUM_SLSH|LF_ALPHA|LF_DOTDATE,
                               0, NULL,
                               CC_SIGN );
                 break;
             default:
                 process_char( LF_ALPHA,
-                              LF_NUM_SPCIM_CHK|LF_DOTDATE|LF_SLASH,
+                              LF_NUM_CKBX|LF_DOTDATE|LF_SLASH,
                               0, NULL,
                               CC_ALPHA );   // most probably :)
                 break;
@@ -200,7 +200,7 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
     }
     // end of the text -treated like new line
     process_char( LF_NEWLINE,
-                  LF_NUM_SPCIM_CHK|LF_ALPHA|LF_FORMATCHAR|
+                  LF_NUM_CKBX|LF_ALPHA|LF_FORMATCHAR|
                   LF_SLASH|LF_DOTDATE|LF_MORE|LF_TAB,
                   LF_EOT, NULL,
                   CC_NEWLINE );
@@ -212,25 +212,26 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks,
               CharClass cc )
 {
     unsigned int lf( lookingfor.front() );
+
+    if( satisfies & LF_NEWLINE )
+    {
+        lookingfor.clear();
+        lookingfor.push_back( LF_NOTHING );
+
+        process_newline();
+    }
+
     if( lf & satisfies )
     {
         if( ( lf & LF_APPLY ) && ( char_last & char_req ) )
         {
-            lookingfor.clear();
-            lookingfor.push_back( LF_NOTHING );
+            if( ! ( satisfies & LF_NEWLINE ) )
+            {
+                lookingfor.clear();
+                lookingfor.push_back( LF_NOTHING );
+            }
 
             ( this->*m_appliers.front() )();    // lookingfor has to be cleared beforehand
-
-            if( satisfies & LF_NEWLINE )
-                process_newline();
-        }
-        else
-        if( satisfies & LF_NEWLINE )
-        {
-            lookingfor.clear();
-            lookingfor.push_back( LF_NOTHING );
-
-            process_newline();
         }
         else
         if( lf & LF_JUNCTION )
@@ -239,11 +240,10 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks,
         }
         else
         {
-            lookingfor.pop_front();
+            if( ! ( lf & LF_APPLY ) )
+                lookingfor.pop_front();
             if( lf & triggers )
-            {
                 ( this->*parsing_triggerer )();
-            }
         }
     }
     else
@@ -257,14 +257,15 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks,
         process_newline();
     }
     else
-    if( ( lf & breaks ) || ( lf & LF_IMMEDIATE ) || ( satisfies & LF_NEWLINE ) )
+    if( ( lf & breaks ) || ( lf & LF_IMMEDIATE ) )
     {
-        lookingfor.clear();
-        lookingfor.push_back( LF_NOTHING );
+        if( ! ( satisfies & LF_NEWLINE ) )
+        {
+            lookingfor.clear();
+            lookingfor.push_back( LF_NOTHING );
+        }
         if( triggers & LF_NOTHING )
             ( this->*parsing_triggerer )();
-        if( satisfies & LF_NEWLINE )
-            process_newline();
     }
     else
     if( lf & triggers )
