@@ -69,8 +69,8 @@ enum LookingFor
 
     LF_PUNCTUATION      = LF_PUNCTUATION_RAW|LF_SLASH|LF_DOTDATE|LF_LESS|LF_MORE|LF_SBB|LF_SBE,
     LF_FORMATCHAR       = LF_ASTERISK|LF_UNDERSCORE|LF_EQUALS|LF_HASH|LF_SBB|LF_SBE,
-    LF_NUM_SPCIM_SLH    = LF_NUMBER|LF_SLASH,   // TODO: rename
-    LF_NUM_SPCIM_CHK    = LF_NUMBER|LF_CHECKBOX, // TODO: rename
+    LF_NUM_SLSH         = LF_NUMBER|LF_SLASH,
+    LF_NUM_CKBX         = LF_NUMBER|LF_CHECKBOX,
     LF_NONSPACE         = LF_PUNCTUATION|LF_MARKUP|LF_ALPHA|LF_NUMBER|LF_AT|LF_CHECKBOX
 };
 
