@@ -131,11 +131,8 @@ class TagPanel
 		void						handle_treeview_row_activated( const Gtk::TreePath&,
 																   Gtk::TreeViewColumn* );
 
-		void						handle_remove_filter( void );
-
 		Gtk::HBox					*m_hbox_tagbar;
 		Gtk::TreeView				*m_treeview_all_tags;
-		Gtk::Button					*m_button_remove_filter;
 
 		Glib::RefPtr< Gtk::TreeStore >
 									m_treestore_all_tags;
