@@ -159,34 +159,41 @@ Date::get_weekday_str( void ) const
 	int y = year % 100;
 	y = y + floor( y / 4 );
 
-	const static int tm[] = { 0, 3, 3, 6, 1, 4, 6, 2, 5, 0, 3, 5 };
-	// FIXME: day names had better be taken from the system
-	const static Glib::ustring days[] = { "Sunday", "Monday", "Tuesday", "Wednesday",
-										  "Thursday", "Friday", "Saturday" };
+	const static int t_m[] = { 0, 3, 3, 6, 1, 4, 6, 2, 5, 0, 3, 5 };
+    struct tm ti;
 
 	int m = get_month() - 1;
-	int d = ( c + y + tm[ m ] + get_day() );
+	int d = ( c + y + t_m[ m ] + get_day() );
 
 	if( !( get_year() % 4 ) && m < 2 )	// leap year!
 		d += 6;
 
-	return days[ d % 7 ];
+    ti.tm_wday = ( d % 7 );
+    char buf[ 32 ];
+    strftime( buf, 32, "%A", &ti );
+	return Glib::ustring( buf );
 }
 
 time_t
 Date::get_ctime( void ) const
 {
-	time_t t;
-	time( &t );
-	struct tm *timeinfo = localtime( &t );
-	timeinfo->tm_year = get_year() - 1900;
-	timeinfo->tm_mon = get_month() - 1;
-	timeinfo->tm_mday = get_day();
-	timeinfo->tm_hour = 0;
-	timeinfo->tm_min = 0;
-	timeinfo->tm_sec = 0;
+	return( get_ctime( m_date ) );
+}
 
-	return( mktime( timeinfo ) );
+time_t
+Date::get_ctime( const Date::date_t d )
+{
+    time_t t;
+    time( &t );
+    struct tm *timeinfo = localtime( &t );
+    timeinfo->tm_year = get_year( d ) - 1900;
+    timeinfo->tm_mon = get_month( d ) - 1;
+    timeinfo->tm_mday = get_day( d );
+    timeinfo->tm_hour = 0;
+    timeinfo->tm_min = 0;
+    timeinfo->tm_sec = 0;
+
+    return( mktime( timeinfo ) );
 }
 
 void
