@@ -109,37 +109,62 @@ class Date
 									Date( unsigned int o1, unsigned int o2 )
 			:	m_date( ORDINAL_FLAG | ( o1 << 10 ) | o2 ) {}
 
+        static date_t               get_today( int order = 0 ) {
+            time_t t = time( NULL );
+            struct tm *ti = localtime( &t );
+            return make_date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday, order );
+		}
+
 		date_t						get_pure( void ) const
 		{ return( m_date & 0xFFFFFC00 ); }
+        static date_t               get_pure( const date_t d )
+        { return( d & 0xFFFFFC00 ); }
 
 		date_t						get_yearmonth( void ) const
 		{ return( m_date & YEARMONTH_FILTER ); }
+        static date_t               get_yearmonth( const date_t d )
+        { return( d & YEARMONTH_FILTER ); }
 
 		unsigned int				get_year( void ) const
 		{ return ( ( m_date & 0x7FF80000 ) >> 19 ); }
+		static unsigned int         get_year( const date_t d )
+        { return ( ( d & 0x7FF80000 ) >> 19 ); }
 
 		Glib::ustring				get_year_str( void ) const;
 		Glib::ustring				get_month_str( void ) const;
 		Glib::ustring				get_day_str( void ) const;
-		Glib::ustring				get_weekday_str( void ) const;
+		Glib::ustring		        get_weekday_str( void ) const;
 
 		unsigned int				get_month( void ) const
 		{ return( ( m_date & 0x78000 ) >> 15 ); }
+        static unsigned int         get_month( const date_t d )
+        { return( ( d & 0x78000 ) >> 15 ); }
 
 		Glib::Date::Month			get_month_glib( void ) const;
 
 		unsigned int				get_day( void ) const
 		{ return( ( m_date & 0x7C00 ) >> 10 ); }
+        static unsigned int         get_day( const date_t d )
+        { return( ( d & 0x7C00 ) >> 10 ); }
 
 		unsigned int				get_order( void ) const
 		{ return( m_date & 0x3FF ); }
+        static unsigned int         get_order( const date_t d )
+        { return( d & 0x3FF ); }
 
 		unsigned int				get_ordinal_order( void ) const
 		{ return( ( m_date & 0x7FFFFC00) >> 10 ); }
+        static unsigned int         get_ordinal_order( const date_t d )
+        { return( ( d & 0x7FFFFC00) >> 10 ); }
+
+        static Date::date_t         get_order_begin( void ) {
+            return ORDINAL_FLAG;
+        }
 
 		Glib::Date					get_glib( void ) const
 		{ return Glib::Date( get_day(), get_month_glib(), get_year() ); }
 		time_t						get_ctime( void ) const;
+        static time_t               get_ctime( const date_t );
 
 		void						set_year( unsigned int y )
 		{
@@ -160,14 +185,16 @@ class Date
 		{ m_date &= 0xFFFFFC00; }
 		void						reset_order_1( void )
 		{ m_date |= 0x1; m_date &= 0xFFFFFC01; }
-		
-		static void					reset_order_1( Date::date_t &date )
+		static void					reset_order_1( date_t &date )
 		{ date |= 0x1; date &= 0xFFFFFC01; }
 
 		Glib::ustring				format_string( void ) const;
+		static Glib::ustring        format_string( const date_t );
 		static Glib::ustring		format_string( const time_t* );
 		static Glib::ustring		format_string_do( const time_t* );
 
+		static date_t               parse_string( const Glib::ustring& );
+
 		bool						is_valid( void ) const
 		{
 			return( Glib::Date::get_days_in_month( get_month_glib(), get_year() ) >= get_day() );
@@ -175,6 +202,8 @@ class Date
 
 		bool						is_ordinal( void ) const
 		{ return( m_date & ORDINAL_FLAG ); }
+        static bool                 is_ordinal( const date_t d )
+        { return( d & ORDINAL_FLAG ); }
 
 		void						forward_months( int months );
 		void						forward_month( void );
@@ -182,8 +211,12 @@ class Date
 
 		void						backward_ordinal_order( void )
 		{ if( get_ordinal_order() > 0 ) m_date -= ORDINAL_STEP; }
+        static void                 backward_ordinal_order( Date::date_t &d )
+        { if( get_ordinal_order( d ) > 0 ) d -= ORDINAL_STEP; }
 		void						forward_ordinal_order( void )
 		{ m_date += ORDINAL_STEP; }
+        static void                 forward_ordinal_order( Date::date_t &d )
+        { d += ORDINAL_STEP; }
 
 		static date_t				make_year( unsigned int y )
 		{ return( y << 19 ); }
@@ -191,6 +224,9 @@ class Date
 		{ return( m << 15 ); }
 		static date_t				make_day( unsigned int m )
 		{ return( m << 10 ); }
+		static date_t               make_date( unsigned int y, unsigned int m, unsigned int d,
+                                               unsigned int o = 0 )
+		{ return( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ); }
 
 	//protected:
 		date_t						m_date;
