@@ -146,7 +146,7 @@ Lifeobase::set_gelem_toolbar( Gtk::Widget *toolbar )
 }
 
 
-// DIALOGEVENT
+// DIALOGEVENT =====================================================================================
 DialogEvent::DialogEvent( const Glib::ustring &title )
 : Gtk::Dialog( title )
 {
@@ -173,32 +173,24 @@ DialogEvent::handle_logout( void )
 	hide();
 }
 
-/*
 
-// wraps Dialog::run() to add activity reporting
-int
-Lifeobase::run_dialog( Gtk::Dialog *dialog, bool flag_connect_event )
+Gtk::Frame*
+create_frame( const Glib::ustring& str_label, Gtk::Widget& content )
 {
-//	if( m_diary.is_encrypted() && m_settings.autologout )
-	if( flag_connect_event )
-	{
-		m_connection_event.disconnect();
-		m_connection_event = dialog->signal_event().connect(
-				sigc::ptr_fun( Lifeobase::handle_event ) );
-	}
+    Gtk::Frame *frame = Gtk::manage( new Gtk::Frame );
+    Gtk::Label *label = Gtk::manage( new Gtk::Label );
 
-	int result = dialog->run();
+    Gtk::Alignment *alignment = Gtk::manage( new Gtk::Alignment );
 
-	if( flag_connect_event )
-	{
-		m_connection_event.disconnect();
-		m_connection_event = m_window->signal_event().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_event ) );
-	}
+    label->set_markup( Glib::ustring::compose( "<b>%1</b>", str_label ) );
+    frame->set_shadow_type( Gtk::SHADOW_NONE );
+    frame->set_label_widget( *label );
+    alignment->set_padding( 0, 0, 12, 0 );
+    alignment->add( content );
+    frame->add( *alignment );
 
-	return result;
+    return frame;
 }
-*/
 
 } // end of namespace LIFEO
 
