@@ -39,11 +39,6 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 :	m_about_dialog( NULL ), m_menu_link( NULL ), m_vbox_login( NULL ), m_hpaned_main( NULL ),
 	m_theme_view( NULL ),
 	m_programpath( argv[ 0 ] ), m_loginstatus( LOGGED_OUT ),
-#ifdef LIFEOGRAPH_DEBUG_BUILD
-	m_flag_ignore_locks( true ),
-#else
-	m_flag_ignore_locks( false ),
-#endif
 	m_flag_open_directly( false ),
 	m_flag_force_welcome( false )
 {
@@ -90,7 +85,7 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 		else
 		if( ! strcmp( argv[ i ], "--ignore-locks" ) )
 		{
-			m_flag_ignore_locks = true;
+			Diary::d->m_flag_ignore_locks = true;
 		}
 		else
 		if( Glib::file_test( argv[ i ], Glib::FILE_TEST_EXISTS ) )
@@ -134,7 +129,7 @@ Lifeograph::on_run( void )
 bool
 Lifeograph::on_event( GdkEvent* )
 {
-	if( m_loginstatus != LOGGED_IN || ! Diary::d->is_encrypted() )
+    if( ! m_settings.autologout || m_loginstatus != LOGGED_IN || ! Diary::d->is_encrypted() )
 		return false;
 	if( m_secondsremaining < LOGOUT_COUNTDOWN )
 		update_title();
@@ -170,6 +165,9 @@ Lifeograph::on_delete_event( GdkEventAny* )
 bool
 Lifeograph::handle_idle()
 {
+    if( ! m_settings.autologout )
+        return false;
+
 	if( m_secondsremaining > 0 )
 	{
 		set_title( Glib::ustring::compose(
@@ -188,67 +186,58 @@ Lifeograph::handle_idle()
 void
 Lifeograph::update_login_file( void )
 {
-	// TODO: this function needs to be optimized
-
-	bool flag_open_ready( false );
+	bool flag_open_ready( true );
 	bool flag_encrypted( false );
 
 	// FIXME: this is not so elegant here:
     if( m_filebuttonrecent->get_recentlist()->size() <= 0 )
 	{
-		m_label_login_info->set_label( _( "Welcome new user!" ) );
-		m_button_open_diary->set_sensitive( false );
-        m_entry_password->set_visible( false );
-		return;
+        m_label_login_info->set_label( _( "Welcome new user!" ) );
+        flag_open_ready = false;
 	}
+    else
+    if( ! Diary::d->set_path( m_filebuttonrecent->get_filename() ) )
+    {
+        m_label_login_info->set_text( _( STRING::DIARY_LOCKED ) );
+        flag_open_ready = false;
+    }
 
-	std::string path = m_filebuttonrecent->get_filename();
-	// TODO: is this still necessary with FILECHOOSERBUTTONRECENT?:
-	if( Glib::file_test( path, Glib::FILE_TEST_IS_DIR ) )
-		return;
+    // TODO: FileButtonRecent should handle this
+//    if( Glib::file_test( path, Glib::FILE_TEST_IS_DIR ) )
+//        return;
 
-	std::string path_lock( path + LOCK_SUFFIX );
-	if( Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
-	{
-		if( m_flag_ignore_locks )
-			print_info( "ignored file lock" );
-		else
-		{
-			m_label_login_info->set_text( _( STRING::DIARY_LOCKED ) );
-			return;
-		}
-	}
-
-	Diary::d->set_path( path );
-
-	switch( Diary::d->read_header() )
-	{
-		case SUCCESS:
-            flag_encrypted = Diary::d->is_encrypted();
-            if( flag_encrypted )
-            {
-                if( m_loginstatus == LOGGED_TIME_OUT )
-                    m_label_login_info->set_text( _( STRING::ENTER_PASSWORD_TIMEOUT ) );
+    if( flag_open_ready )
+    {
+        flag_open_ready = false;
+        switch( Diary::d->read_header() )
+        {
+            case SUCCESS:
+                flag_encrypted = Diary::d->is_encrypted();
+                if( flag_encrypted )
+                {
+                    if( m_loginstatus == LOGGED_TIME_OUT )
+                        m_label_login_info->set_text( _( STRING::ENTER_PASSWORD_TIMEOUT ) );
+                    else
+                        m_label_login_info->set_text( _( STRING::ENTER_PASSWORD ) );
+                    flag_open_ready = ( m_entry_password->get_text_length() > 0 );
+                }
                 else
-                    m_label_login_info->set_text( _( STRING::ENTER_PASSWORD ) );
-                flag_open_ready = ( m_entry_password->get_text_length() > 0 );
-			}
-			else
-			{
-                m_label_login_info->set_text( _( STRING::DB_IS_NOT_ENCRYPTED ) );
-				flag_open_ready = true;
-			}
-			break;
-		case INCOMPATIBLE_FILE:
-            m_label_login_info->set_text( _( STRING::INCOMPATIBLE_DB ) );
-			break;
-		case CORRUPT_FILE:
-            m_label_login_info->set_text( _( STRING::CORRUPT_DB ) );
-			break;
-		default:
-            m_label_login_info->set_text( _( STRING::FAILED_TO_OPEN_DB ) );
-            break;
-	}
+                {
+                    m_label_login_info->set_text( _( STRING::DB_IS_NOT_ENCRYPTED ) );
+                    flag_open_ready = true;
+                }
+                break;
+            case INCOMPATIBLE_FILE:
+                m_label_login_info->set_text( _( STRING::INCOMPATIBLE_DB ) );
+                break;
+            case CORRUPT_FILE:
+                m_label_login_info->set_text( _( STRING::CORRUPT_DB ) );
+                break;
+            default:
+                m_label_login_info->set_text( _( STRING::FAILED_TO_OPEN_DB ) );
+                break;
+        }
+    }
 
     if( flag_open_ready && ( ! flag_encrypted ) && m_flag_open_directly )
     {
@@ -357,8 +346,8 @@ Lifeograph::handle_button_opendb_clicked( void )
 	}
 	if( Diary::d->is_encrypted() )
 	{
-		std::string t_string = m_entry_password->get_text();
-		Diary::d->set_passphrase( t_string );
+		std::string passphrase = m_entry_password->get_text();
+		Diary::d->set_passphrase( passphrase );
 	}
 
 	switch( Diary::d->read_body() )
@@ -423,7 +412,7 @@ Lifeograph::handle_textview_link_activated( const Date &date )
 		entries->at( 0 )->show();
 	else
 	{
-		Entry *entry = Diary::d->create_entry( date );
+		Entry *entry = Diary::d->create_entry( date.m_date );
 		update_entry_list();
 		entry->show();
 	}
@@ -631,11 +620,11 @@ Lifeograph::get_element_row( DiaryElement *element )
 {
 	switch( element->get_type() )
 	{
-		case DiaryElement::IT_ENTRY:
-		case DiaryElement::IT_CHAPTER:
+		case DiaryElement::ET_ENTRY:
+		case DiaryElement::ET_CHAPTER:
 			return( m_panel_diary->get_row( element->m_list_data->treepath ) );
 
-		case DiaryElement::IT_TAG:
+		case DiaryElement::ET_TAG:
 			return( m_panel_tag->get_row( element->m_list_data->treepath ) );
 		default:
 			return( Gtk::TreeRow() );
@@ -692,7 +681,7 @@ void
 Lifeograph::update_toolbar()
 {
 	bool flag_sensitive =
-			m_panel_main->get_cur_elem_type() == DiaryElement::IT_ENTRY ?
+			m_panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY ?
 					m_entrycount > 1 :
 					m_panel_diary->m_treeview_entries->m_treestore_entries->children().size() > 1;
 
@@ -727,7 +716,7 @@ Lifeograph::update_entryliststyle( void )
 
 	update_entry_list();
 
-	if( m_panel_main->get_cur_elem_type() != DiaryElement::IT_ENTRY )
+	if( m_panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
 		Diary::d->show();
 
 	m_panel_diary->m_treeview_entries->columns_autosize();
