@@ -322,12 +322,12 @@ PanelDiary::handle_logout( void )
 void
 PanelDiary::show( const DiaryElement *element )
 {
-	if( element->get_type() >= DiaryElement::IT_DIARY )
+	if( element->get_type() >= DiaryElement::ET_DIARY ) // if a list element
 		m_treeview_entries->present_element( element );
 	else
 		m_treeview_entries->get_selection()->unselect_all();
 
-	if( element->get_type() > DiaryElement::IT_DIARY && ! element->get_date().is_ordinal() )
+	if( element->get_type() > DiaryElement::ET_DIARY && ! element->get_date().is_ordinal() )
     {
         select_date_in_calendar( element->get_date() );
         m_menuitem_add_entry->set_sensitive( true );
@@ -382,7 +382,7 @@ PanelDiary::handle_entry_filter_changed( void )
 		if( Lifeobase::m_entrycount > 0 )
 		{
 			TextviewDiary::m_buffer->set_search_str( filterstring );
-			if( Lifeobase::base->get_cur_elem_type() == DiaryElement::IT_ENTRY )
+			if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 				TextviewDiary::m_buffer->select_searchstr_next();
 		}
 
@@ -486,7 +486,7 @@ PanelDiary::handle_add_entry( void )
 
     if( day )
     {
-        Entry *entry( Diary::d->create_entry( Date( year, month + 1, day ) ) );
+        Entry *entry( Diary::d->create_entry( Date::make_date( year, month + 1, day ) ) );
 
         update_entry_list();
         update_calendar();
@@ -551,7 +551,7 @@ PanelDiary::go_prev_match( void )
 		return;
 
 	// TODO: move to Entry
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::IT_ENTRY )
+	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 		if( TextviewDiary::m_buffer->select_searchstr_previous() )
 			return;
 
@@ -575,7 +575,7 @@ PanelDiary::go_next_match( void )
 		return;
 
 	// TODO: move to Entry
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::IT_ENTRY )
+	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 		if( TextviewDiary::m_buffer->select_searchstr_next() )
 			return;
 
@@ -609,7 +609,7 @@ PanelDiary::replace_all_matches( void )
 
 	Diary::d->replace_text( m_entry_replace->get_text() );
 	// update current entry:
-	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::IT_ENTRY )
+	if( Lifeobase::base->get_cur_elem_type() == DiaryElement::ET_ENTRY )
 	{
 		Entry *entry = dynamic_cast< Entry* >( Lifeobase::base->get_cur_elem() );
 		TextviewDiary::m_buffer->set_richtext( entry );
@@ -631,7 +631,7 @@ PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter &iter,
 		//return;
 
 	DiaryElement *element = ( * iter )[ ListData::colrec->ptr ];
-	if( element->get_type() == DiaryElement::IT_CHAPTER )
+	if( element->get_type() == DiaryElement::ET_CHAPTER )
 	{
 		Chapter *chapter = dynamic_cast< Chapter* >( element );
 		chapter->set_expanded( m_treeview_entries->row_expanded( path ) );
