@@ -44,21 +44,15 @@ class PanelDiary
 		void					present_current_row( void );
 		void					show_prev_session_elem( void );
 
-		void					handle_calendar_doubleclicked( void );
 		void					handle_calendar_monthchanged( void );
 		void					handle_calendar_dayselected( void );
-		void					handle_calendar_button_pressed( GdkEventButton* );
 		void					select_date_in_calendar( const Date& );
 
 		void					handle_filter_favorites_toggled( void );
+		void					remove_filters( void );
 		void					handle_login( void );
 		void					handle_logout( void );
 
-		bool					make_path_deeper_last( Gtk::TreePath& );
-		bool					move_path_next( Gtk::TreePath& );
-		void					go_up( bool );
-		void					go_down( bool );
-
 		void					handle_entry_filter_changed( void );
 		void					go_prev_match( void );
 		void					go_next_match( void );
@@ -71,22 +65,30 @@ class PanelDiary
 															  const Gtk::TreePath& );
 
 	protected:
-		void					create_chapter( const Date& );
+        void                    handle_add_entry( void );
+        void                    handle_add_topic( void );
+        void                    handle_add_chapter( void );
 
 		WidgetEntryList			*m_treeview_entries;
 
 		Gtk::Calendar			*m_calendar;
 		EntryIdletext			*m_entry_filter;
 		EntryIdletext			*m_entry_replace;
-		Gtk::ToolButton			*m_button_match_prev;
-		Gtk::ToolButton			*m_button_match_next;
-		Gtk::Toolbar			*m_toolbar_replace;
-		Gtk::ToolButton			*m_toolbutton_replace;
-		Gtk::ToolButton			*m_toolbutton_replace_all;
+        Gtk::Button             *m_button_match_prev;
+        Gtk::Button             *m_button_match_next;
+        Gtk::HBox               *m_toolbar_replace;
+        Gtk::Button             *m_button_replace;
+        Gtk::Button             *m_button_replace_all;
 
 		Gtk::RadioMenuItem		*m_menuitem_sort_by_date;
 		Gtk::RadioMenuItem		*m_menuitem_sort_by_size;
-		Gtk::CheckMenuItem		*m_menuitem_filter_favorites;
+
+		Gtk::ToggleButton       *m_togglebtn_filter_favorites;
+		Gtk::Button             *m_button_remove_filters;
+
+        Gtk::ImageMenuItem      *m_menuitem_add_entry;
+        Gtk::ImageMenuItem      *m_menuitem_add_topic;
+        Gtk::ImageMenuItem      *m_menuitem_add_chapter;
 
 		// LISTING TMP VARIABLES
 		void					add_chapter_category_to_list( const CategoryChapters* );
@@ -98,8 +100,6 @@ class PanelDiary
 	friend class Lifeograph;
 };
 
-
-
 } // end of namespace LIFEO
 
 #endif
