@@ -231,7 +231,6 @@ void
 EntryView::handle_login( void )
 {
 	m_textviewdiary->m_buffer->handle_login();
-	m_tag_widget->populate();
 }
 
 void
@@ -285,7 +284,7 @@ EntryView::handle_drag_data_received(
 		{
 			DiaryElement *element = Lifeobase::base->get_dragged_elem();
 			if( element != NULL )
-                if( element->get_type() == DiaryElement::IT_ENTRY )
+                if( element->get_type() == DiaryElement::ET_ENTRY )
                     TextviewDiary::m_buffer->insert_link( element );
 			break;
 		}
@@ -364,8 +363,11 @@ EntryView::dismiss_entry( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
-	Lifeobase::base->remove_element_from_history( m_ptr2entry );
+    // first make sure that entry to be deleted is completely out of business...
+    // ...else dark forces may take action and cause SEGFAULT:
+    Diary::d->show();
 
+	Lifeobase::base->remove_element_from_history( m_ptr2entry );
 	Diary::d->dismiss_entry( m_ptr2entry );
 
 	Lifeobase::m_internaloperation++;
@@ -435,6 +437,7 @@ EntryView::handle_button_tag_clicked( void )
 			tag = Diary::d->create_tag( filter );
 			m_ptr2entry->add_tag( tag );
 			Lifeobase::base->update_tag_list();
+            m_tag_widget->populate();
 			break;
 		case TO_ADD:
 			tag = Diary::d->get_tags()->get_tag( filter );
@@ -537,6 +540,8 @@ EntryView::show( Entry &entry )
 
 	Lifeobase::m_internaloperation--;
 
+    m_tag_widget->populate();
+
 	PRINT_DEBUG( "entry shown" );
 }
 
