@@ -259,6 +259,8 @@ TagView::dismiss_tag( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
+    Diary::d->show();
+
 	Lifeobase::base->remove_element_from_history( m_ptr2tag );
 
 	// clear filter if necessary:
@@ -270,8 +272,6 @@ TagView::dismiss_tag( void )
 	}
 	Diary::d->dismiss_tag( m_ptr2tag );
 	Lifeobase::base->update_tag_list();
-
-	Diary::d->show();
 }
 
 bool
@@ -357,10 +357,10 @@ CategoryTagsView::dismiss_category( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
-	Lifeobase::base->remove_element_from_history( m_ptr2category );
+    Diary::d->show();
 
+	Lifeobase::base->remove_element_from_history( m_ptr2category );
 	// TODO: offer merging with a category
-	Diary::d->show();
 	Diary::d->dismiss_tag_ctg( m_ptr2category );
 	Lifeobase::base->update_tag_list();
 	Lifeobase::base->update_tag_categories();
@@ -433,10 +433,9 @@ ChapterView::dismiss_chapter( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
+    Diary::d->show();
+
 	Lifeobase::base->remove_element_from_history( m_ptr2chapter );
-
-	Diary::d->show();
-
 	Diary::d->dismiss_chapter( m_ptr2chapter );
 	Lifeobase::base->update_entry_list();
 }
@@ -533,7 +532,7 @@ ChapterView::update_labels( void )
 void
 ChapterView::add_new_entry( void )
 {
-	Diary::d->create_entry( m_ptr2chapter->get_free_order() );
+	Diary::d->create_entry( m_ptr2chapter->get_free_order().m_date );
 
 	Lifeobase::base->update_entry_list();
 	Lifeobase::base->update_calendar();
@@ -726,6 +725,8 @@ ThemeView::dismiss_theme( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
+    Diary::d->show();
+
 	Lifeobase::base->remove_element_from_history( m_ptr2theme );
 
 	Theme *theme = m_ptr2theme; // always be on the safe side
@@ -1164,6 +1165,8 @@ DiaryView::dismiss_cur_chapter_ctg( void )
 	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
+    Diary::d->show();
+
 	m_ptr2diary->dismiss_chapter_ctg( m_ptr2diary->m_ptr2chapter_ctg_cur );
 	update_combobox_chapter_ctg();
 }
