@@ -34,7 +34,7 @@
 namespace LIFEO
 {
 
-// DIARY ELEMENT VIEW ==========================================================
+// DIARY ELEMENT VIEW ==============================================================================
 class GUIElement // BEWARE: subject to removal
 {
 	public:
@@ -46,8 +46,8 @@ class GUIElement // BEWARE: subject to removal
 								Signal_Date;
 };
 
-// TAG VIEW ====================================================================
-class TagView : public Tag::Shower
+// TAG VIEW ========================================================================================
+class TagView : public ElementShower< Tag >
 {
 	public:
 								TagView( void );
@@ -94,8 +94,8 @@ class TagView : public Tag::Shower
 
 };
 
-// TAG CATEGORY VIEW ===========================================================
-class CategoryTagsView : public CategoryTags::Shower
+// TAG CATEGORY VIEW ===============================================================================
+class CategoryTagsView : public ElementShower< CategoryTags >
 {
 	public:
 								CategoryTagsView( void );
@@ -116,8 +116,8 @@ class CategoryTagsView : public CategoryTags::Shower
 		CategoryTags			*m_ptr2category;
 };
 
-// CHAPTER VIEW ================================================================
-class ChapterView : public Chapter::Shower
+// CHAPTER VIEW ====================================================================================
+class ChapterView : public ElementShower< Chapter >
 {
 	public:
 								ChapterView( void );
@@ -142,20 +142,6 @@ class ChapterView : public Chapter::Shower
 		Gtk::Entry				*m_entry_name;
 		Gtk::Button				*m_button_name_apply;
 
-		//Gtk::ComboBox			*m_combo_type;
-		//enum ChapterType { CT_TEMPORAL, CT_ORDINAL };
-		//class ColrecChapterType : public Gtk::TreeModel::ColumnRecord
-		//{
-			//public:
-				//ColrecChapterType() { add( name ); add( type ); }
-				//Gtk::TreeModelColumn< Glib::ustring >	name;
-				//Gtk::TreeModelColumn< ChapterType >		type;
-		//};
-
-		//Glib::RefPtr< Gtk::ListStore >
-								//m_liststore_chapter_type;
-		//ColrecChapterType		colrec_chapter_type;
-
 		Gtk::Label				*m_label_period;
 		Gtk::HBox				*m_hbox_period;
 		Gtk::Entry				*m_entry_begins;
@@ -167,8 +153,8 @@ class ChapterView : public Chapter::Shower
 		Chapter					*m_ptr2chapter;
 };
 
-// THEME VIEW ==================================================================
-class ThemeView : public Theme::Shower
+// THEME VIEW ======================================================================================
+class ThemeView : public ElementShower< Theme >
 {
 	public:
 								ThemeView( void );
@@ -186,6 +172,8 @@ class ThemeView : public Theme::Shower
 		Gtk::ColorButton		*m_colorbutton_heading;
 		Gtk::ColorButton		*m_colorbutton_subheading;
 		Gtk::ColorButton		*m_colorbutton_highlight;
+		Gtk::EventBox           *m_eventbox_preview;
+		Gtk::Label              *m_label_preview;
 
 		Gtk::Button				*m_button_duplicate;
 		Gtk::Button				*m_button_dismiss;
@@ -197,14 +185,15 @@ class ThemeView : public Theme::Shower
 		void					handle_name_applied( void );
 		void					handle_font_changed( void );
 		void					handle_color_changed( void );
+		void					update_preview( void );
 
 		void					duplicate( void );
 		void					make_default( void );
 		void					dismiss_theme( void );
 };
 
-// DIARY VIEW ==================================================================
-class DiaryView : public Diary::Shower
+// DIARY VIEW ======================================================================================
+class DiaryView : public ElementShower< Diary >
 {
 	public:
 								DiaryView( void );
@@ -236,8 +225,6 @@ class DiaryView : public Diary::Shower
 		bool					is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
 												  const Gtk::TreeIter );
 
-		void					add_topic( void );
-
 		Gtk::VBox				*m_vbox_diary;
 		Gtk::Alignment			*m_alignment_toolbar;
 		Gtk::Label				*m_label_path;
@@ -245,6 +232,7 @@ class DiaryView : public Diary::Shower
 		Gtk::Button				*m_button_logoutwosaving;
 		Gtk::CheckButton		*m_checkbutton_autologout;
 		Gtk::Button				*m_button_password;
+        WidgetChart             *m_widgetchart;
 
 		// STARTUP
 		Gtk::ComboBox			*m_combobox_startup_type;
@@ -287,6 +275,7 @@ class DiaryView : public Diary::Shower
 		// DIALOGS
 		DialogPassword			*m_dialog_password;
 		DialogImport			*m_dialog_import;
+		DialogExport			*m_dialog_export;
 
 		Diary					*m_ptr2diary;
 
