@@ -67,7 +67,7 @@ class WidgetChart : public Gtk::DrawingArea
 		const static float			offset_label = 5.0;
 		const static float			label_height = 12.0;
 		const static float			bar_height = 25.0;
-		const static float			OVERVIEW_HEIGHT = 70.0;
+		const static float			OVERVIEW_COEFFICIENT = 20;
 		const static float			COLUMN_WIDTH_MIN = 45.0;
 		// CALCULATED CONSTANTS
 		const static float			label_y = 5.0 + 12.0;	// = offset_label + label_height;
