@@ -96,7 +96,7 @@ WidgetEntryList::go_up( bool flag_entry_operation )
     if( elem == NULL )
         return;
     else
-    if( elem->get_type() < DiaryElement::IT_DIARY ) // not list element
+    if( elem->get_type() < DiaryElement::ET_DIARY ) // not list element
         return;
 
     Gtk::TreePath path( m_treemodelsort_entries->convert_child_path_to_path(
@@ -119,7 +119,7 @@ WidgetEntryList::go_up( bool flag_entry_operation )
     }
     // repeat until an entry is found if that is what we are looking for
     // BEWARE: do not set this flag when there is no entry in the list
-    while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
+    while( flag_entry_operation && elem->get_type() != DiaryElement::ET_ENTRY );
 
     PRINT_DEBUG( "previous path: " + path.to_string() );
 
@@ -136,7 +136,7 @@ WidgetEntryList::go_down( bool flag_entry_operation )
     if( elem == NULL )
         return;
     else
-    if( elem->get_type() < DiaryElement::IT_DIARY ) // not list element
+    if( elem->get_type() < DiaryElement::ET_DIARY ) // not list element
         return;
 
     Gtk::TreePath path( m_treemodelsort_entries->convert_child_path_to_path(
@@ -161,7 +161,7 @@ WidgetEntryList::go_down( bool flag_entry_operation )
     }
     // repeat until an entry is found if that is what we are looking for
     // BEWARE: do not set this flag when there is no entry in the list
-    while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
+    while( flag_entry_operation && elem->get_type() != DiaryElement::ET_ENTRY );
 
     PRINT_DEBUG( "next path: " + path.to_string() );
 
@@ -230,8 +230,8 @@ WidgetEntryList::find_element( const DiaryElement *element ) const
 		}
 		else
 		{
-			if( element->get_type() == DiaryElement::IT_ENTRY &&
-				list_elem->get_type() != DiaryElement::IT_ENTRY )
+			if( element->get_type() == DiaryElement::ET_ENTRY &&
+				list_elem->get_type() != DiaryElement::ET_ENTRY )
 				if( element->get_date() > list_elem->get_date() )
 					for( Gtk::TreeIter itr2 = ( *iter )->children().begin();
 						 itr2 != ( *iter )->children().end();
@@ -415,12 +415,12 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context
 	{
 		Gtk::TreeRow row = * m_treemodelsort_entries->get_iter( path );
 		DiaryElement *element( row[ ListData::colrec->ptr ] );
-		if( element->get_type() == DiaryElement::IT_DIARY ||
-			m_element_dragged->get_type() == DiaryElement::IT_DIARY )
+		if( element->get_type() == DiaryElement::ET_DIARY ||
+			m_element_dragged->get_type() == DiaryElement::ET_DIARY )
 			retval = false;
 		// chapters cannot be dropped
 		else
-		if( m_element_dragged->get_type() == DiaryElement::IT_CHAPTER )/*&&
+		if( m_element_dragged->get_type() == DiaryElement::ET_CHAPTER )/*&&
 			! m_element_dragged->get_date().is_ordinal() )*/
 			retval = false;
 		// chapters can only be dropped on ordinal chapters
@@ -431,7 +431,7 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context
 			retval = false;*/
 		// do not allow dropping on its own folder
 		else
-		if( element->get_type() == DiaryElement::IT_CHAPTER &&
+		if( element->get_type() == DiaryElement::ET_CHAPTER &&
 			element->get_date().get_pure() == m_element_dragged->get_date().get_pure() )
 			retval = false;
 		// do not allow dropping on itself
@@ -464,10 +464,10 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext > &context,
 	{
 		if( m_element_dragged != NULL || m_element_drop_target != NULL )
 		{
-			if( m_element_dragged->get_type() == DiaryElement::IT_ENTRY )
+			if( m_element_dragged->get_type() == DiaryElement::ET_ENTRY )
 			{
 				Entry *entry( dynamic_cast< Entry* >( m_element_dragged ) );
-				if( m_element_drop_target->get_type() == DiaryElement::IT_CHAPTER )
+				if( m_element_drop_target->get_type() == DiaryElement::ET_CHAPTER )
 				{
 					Chapter *chapter( dynamic_cast< Chapter* >( m_element_drop_target ) );
 					Diary::d->set_entry_date( entry, chapter->get_free_order() );
@@ -538,7 +538,7 @@ WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator &itr1,
 	if( !( item1 && item2 ) )
 		return 0;
 	else
-	if( item1->get_type() == DiaryElement::IT_DIARY )
+	if( item1->get_type() == DiaryElement::ET_DIARY )
 	return -1;
 
 	int direction( ( item1->get_date().is_ordinal() && item2->get_date().is_ordinal() ) ? -1 : 1 );
