@@ -44,6 +44,8 @@ class WidgetEntryList : public Gtk::TreeView
 
 			void						present_element( const DiaryElement* );
 			void						expand_element( const DiaryElement* );
+            void                        go_up( bool );
+            void                        go_down( bool );
 			void						set_sorting_criteria( void );
 			void						handle_sorting_criteria_changed( SortingCriteria );
 
@@ -73,6 +75,8 @@ class WidgetEntryList : public Gtk::TreeView
 
 			bool						on_button_press_event( GdkEventButton* );
 			bool						on_button_release_event( GdkEventButton* );
+            bool                        on_key_press_event( GdkEventKey* );
+
 			void						on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& );
 			void						on_drag_data_get(
 												const Glib::RefPtr< Gdk::DragContext >&,
@@ -87,6 +91,9 @@ class WidgetEntryList : public Gtk::TreeView
 												//guint, guint );
 
 			//DiaryEntryView*				get_treerow_ptr_entry( const Gtk::TreeRow& );
+
+            bool                        make_path_deeper_last( Gtk::TreePath& );
+            bool                        move_path_next( Gtk::TreePath& );
 };
 
 
