@@ -490,7 +490,7 @@ TextbufferDiary::apply_link_id( void )
 
     if( element != NULL )
     {
-        if( element->get_type() == DiaryElement::IT_ENTRY )
+        if( element->get_type() == DiaryElement::ET_ENTRY )
         {
             Gtk::TextIter iter_tab( get_iter_at_offset( pos_tab ) );
             Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
