@@ -36,6 +36,7 @@ extern "C"
 #include "undo.hpp"
 #include "diarydata.hpp"
 #include "entry.hpp"
+#include "entry_parser.hpp"
 
 
 namespace LIFEO
@@ -43,69 +44,6 @@ namespace LIFEO
 
 const int		UNDO_MERGE_TIMEOUT = 3;
 
-enum LookingFor
-{
-	LF_NOTHING			= 0x1,
-	LF_NEWLINE			= 0x2,
-	LF_NONSPACE			= 0x4,
-	LF_SPACE			= 0x8,		// space that will come eventually
-	LF_TAB				= 0x10,
-	LF_SPACE_IMMEDIATE	= 0x20,		// immediate space char (" ")
-
-	LF_ASTERISK			= 0x40,		// bold
-	LF_UNDERSCORE		= 0x80,		// italic
-	LF_EQUALS			= 0x100,	// strikethrough
-	LF_HASH				= 0x400,	// highlight
-	LF_FORMATCHAR		= 0x5C0,	// all above
-
-	LF_SLASH			= 0x800,
-	LF_NUMBER			= 0x2000,
-	LF_AT				= 0x4000,	// email
-	LF_CHECKBOX			= 0x8000,
-
-	LF_DOTYM			= 0x10000,
-	LF_DOTMD			= 0x20000,
-	LF_DOTDATE			= 0x30000,	// DOTMD | DOTYM
-
-	LF_LESS				= 0x80000,	// tagging
-	LF_MORE				= 0x100000,
-	LF_TILDE			= 0x200000,
-
-	LF_APPLY			= 0x1000000,
-	LF_APPLY_LINK		= 0x3000000,
-	LF_APPLY_LINK_DATE	= 0x5000000,
-	LF_APPLY_MARKUP		= 0x7000000,
-	LF_APPLY_HEADING	= 0x9000000,
-	LF_APPLY_SUBHEADING	= 0xB000000,
-	LF_APPLY_LINK_ID	= 0xD000000,
-
-	LF_APPLY_DOTMD		= 0xF000000,
-	LF_APPLY_DOTYM		= 0x11000000,
-
-	LF_APPLY_TAG		= 0x13000000,
-	
-	LF_APPLY_CHECK_CAN	= 0x51000000,
-	LF_APPLY_CHECK_UNF	= 0x61000000,
-	LF_APPLY_CHECK_FIN	= 0x71000000,
-
-	LF_NUM_SPCIM_SLH	= LF_NUMBER|LF_SPACE_IMMEDIATE|LF_SLASH,
-	LF_NUM_SPCIM_CHK	= LF_NUMBER|LF_SPACE_IMMEDIATE|LF_CHECKBOX
-};
-
-enum CharClass
-{
-	CC_NONE				= 0,
-	CC_NUMBER			= 0x10,
-	CC_ALPHA			= 0x20,
-	CC_ALPHANUM			= 0x30,
-	CC_SIGN				= 0x40,
-
-	CC_SPACE			= 0x100,
-	CC_TAB				= 0x200,
-	CC_NEWLINE			= 0x400,
-	CC_SEPARATOR		= 0x700
-};
-
 enum LinkStatus
 {
 	LS_OK,
@@ -119,14 +57,14 @@ enum LinkStatus
 	LS_FILE_UNKNOWN
 };
 
-
 class UndoEdit : public Undoable
 {
 	public:
-							UndoEdit ( int position,
-									   const Glib::ustring& text,
-									   UndoableType type )
+							UndoEdit( int position,
+                                      const Glib::ustring& text,
+                                      UndoableType type )
 		: Undoable( "placeholder", type ), m_position( position ), m_text( text ) { }
+		virtual             ~UndoEdit() {}   //needed because of virtual methods
 
 		unsigned int		get_position (void) const
 		{
@@ -321,7 +259,7 @@ class LinkCheck : public Link
 };
 
 
-class TextbufferDiary : public Gtk::TextBuffer
+class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 {
 	public:
 		typedef void ( TextbufferDiary::*ParsingApplierFn )( void );
@@ -341,9 +279,8 @@ class TextbufferDiary : public Gtk::TextBuffer
 		Link*						get_link( const Gtk::TextIter& ) const;
 
 		void						set_richtext( Entry* );
-		void						reparse( void );
 
-		void						set_searchstr( const Glib::ustring& );
+		void						set_search_str( const Glib::ustring& );
 		bool						select_searchstr_previous( void );
 		bool						select_searchstr_next( void );
 
@@ -354,6 +291,8 @@ class TextbufferDiary : public Gtk::TextBuffer
 		void						toggle_highlight( void );
 		void						toggle_strikethrough( void );
 
+        void                        show_comments( bool );
+
 		void						handle_indent( void );
 		void						handle_unindent( void );
 
@@ -391,88 +330,59 @@ class TextbufferDiary : public Gtk::TextBuffer
 		bool						process_new_line( void );
 
 		// PARSING
-		void						parse( unsigned int, unsigned int );
+		void                        parse( unsigned int, unsigned int );
+        void                        reparse( void );
 
-		void						process_char( unsigned int, unsigned int,
-												  unsigned int,
-												  ParsingApplierFn,
-												  CharClass );
+		void						apply_hidden_link_tags( Gtk::TextIter&,
+		                                    const Glib::RefPtr< Tag >& );
 
-		void						apply_markup( const Glib::RefPtr<Tag>& );
+		void						apply_heading( void );
+		void						apply_subheading( void );
+		void						apply_bold( void );
+		void						apply_italic( void );
+		void						apply_strikethrough( void );
+		void						apply_highlight( void );
+        void                        apply_comment( void );
+        void                        apply_ignore( void );
+		void						apply_link( void );
+		void						apply_link_date( void );
+		void						apply_link_id( void );
+		void						apply_check_ccl( void );
+		void						apply_check_unf( void );
+		void						apply_check_fin( void );
+        void                        apply_match( void );
+		void                        apply_markup( const Glib::RefPtr<Tag>& );
 
-		void						apply_hidden_link_tags( Gtk::TextIter& );
+		gunichar                    get_char_at( int );
 
-		void						parsing_triggerer_subheading( void );
-		void						parsing_triggerer_bold( void );
-		void						parsing_triggerer_italic( void );
-		void						parsing_triggerer_strikethrough( void );
-		void						parsing_triggerer_highlight( void );
-		void						parsing_triggerer_link( void );
-		void						parsing_triggerer_link_at( void );
-		void						parsing_triggerer_link_date( void );
-		void						parsing_triggerer_link_hidden_tab( void );
-		void						parsing_triggerer_list( void );
-		void						parsing_junction_list( void );
-
-		void						parsing_applier_heading( void );
-		void						parsing_applier_subheading( void );
-		void						parsing_applier_bold( void );
-		void						parsing_applier_italic( void );
-		void						parsing_applier_strikethrough( void );
-		void						parsing_applier_highlight( void );
-		void						parsing_applier_link( void );
-		void						parsing_applier_link_date( void );
-		void						parsing_applier_link_id( void );
-		void						parsing_applier_check_can( void );
-		void						parsing_applier_check_unf( void );
-		void						parsing_applier_check_fin( void );
-
-		void						parsing_handler_number( void );
-		void						parsing_applier_dotym( void );
-		void						parsing_applier_dotmd( void );
-
-		Gtk::TextIter				parser_iter_start;
-		Gtk::TextIter				parser_iter_current;
-		Gtk::TextIter				parser_iter_word;
-		Gtk::TextIter				parser_iter_1;		// helper
-		CharClass					parser_char_last;
-		gunichar					parser_char_current;
-		Glib::ustring				parser_word_last;
-		unsigned int				parser_int_last;
-		Date						parser_date_link;
 		Glib::ustring::size_type	parser_open_tag_begin;
 		Glib::ustring::size_type	parser_open_tag_end;
 		bool						parser_open_tag_is_link;
 		Glib::ustring::size_type	parser_offset_insert_prev;
-		std::deque< unsigned int >	parser_lookingfor;
-
-		std::deque< unsigned int >	m_plan_subheading;
-		std::deque< unsigned int >	m_plan_bold;
-
-		std::map< unsigned int, ParsingApplierFn >
-									m_parsers;
 
 		// LINKS
 		void						clear_links( int, int );
 		void						clear_links( void );
 
-		// TAGS
-		// TODO: move these program-wide objects out of this class as...
-		// ...there may be other instances of TextbufferDiary in the future
-		static Glib::RefPtr< Tag >	m_tag_heading;
-		static Glib::RefPtr< Tag >	m_tag_subheading;
-		static Glib::RefPtr< Tag >	m_tag_match;
-		static Glib::RefPtr< Tag >	m_tag_markup;
-		Glib::RefPtr< Tag >			m_tag_markup_link;
-		Glib::RefPtr< Tag >			m_tag_hidden;
-		static Glib::RefPtr< Tag >	m_tag_bold;
-		static Glib::RefPtr< Tag >	m_tag_italic;
-		static Glib::RefPtr< Tag >	m_tag_strikethrough;
-		static Glib::RefPtr< Tag >	m_tag_highlight;
-		static Glib::RefPtr< Tag >	m_tag_link;
-		static Glib::RefPtr< Tag >	m_tag_link_broken;
-		Glib::RefPtr< Tag >			m_tag_link_hidden;
-		static Glib::RefPtr< Tag >	m_tag_checkbox;
+        // TAGS
+        // TODO: move these program-wide objects out of this class as...
+        // ...there may be other instances of TextbufferDiary in the future
+        Glib::RefPtr< Tag >         m_tag_heading;
+        Glib::RefPtr< Tag >         m_tag_subheading;
+        Glib::RefPtr< Tag >         m_tag_match;
+        Glib::RefPtr< Tag >         m_tag_markup;
+        Glib::RefPtr< Tag >         m_tag_markup_link;
+        Glib::RefPtr< Tag >         m_tag_hidden;
+        Glib::RefPtr< Tag >         m_tag_bold;
+        Glib::RefPtr< Tag >         m_tag_italic;
+        static Glib::RefPtr< Tag >  m_tag_strikethrough;
+        static Glib::RefPtr< Tag >  m_tag_highlight;
+        Glib::RefPtr< Tag >         m_tag_comment;
+        Glib::RefPtr< Tag >         m_tag_region;
+        Glib::RefPtr< Tag >         m_tag_link;
+        Glib::RefPtr< Tag >         m_tag_link_broken;
+        Glib::RefPtr< Tag >         m_tag_link_hidden;
+        static Glib::RefPtr< Tag >  m_tag_checkbox;
 
 		// THEMING
 		static Gdk::Color			m_theme_color_match;
@@ -481,8 +391,6 @@ class TextbufferDiary : public Gtk::TextBuffer
 		static Gdk::Color			m_theme_color_linkbroken;
 
 		// OTHER VARIABLES
-		Glib::ustring				m_searchstr;
-		bool						m_option_search;
 		bool						m_flag_settextoperation;
 		bool						m_flag_ongoingoperation;
 		bool						m_flag_parsing;
@@ -506,6 +414,8 @@ class TextviewDiary : public Gtk::TextView
 									TextviewDiary( BaseObjectType*,
 												   const Glib::RefPtr<Gtk::Builder>& );
 
+        void                        set_richtext( Entry* );
+
 		static TextbufferDiary		*m_buffer;
 
 	protected:
